@@ -17,6 +17,9 @@ makedocs(;
     doctest = ("doctest=true" in ARGS),
     pages=[
         "Home" => "index.md",
+        "Background Knowledge" => "background.md",
+        "Tutorial" => "tutorial.md",
+        "Choosing Optimizers" => "optimizers.md",
         "Reference" => "ref.md",
     ],
 )
